@@ -28,21 +28,24 @@ int main(argc,argv)
 int argc;
 char **argv;
 {
-	FILE *input,*output;
-	int i,j,k,trcknt,mapknt;
+	FILE *input;
+	int i,j,trcknt,mapknt,nbytes;
 	char **from,**to,*value;
 	char *lbracket,*rbracket;
 	int offset;
+	char *bufptr;
 	int numsmpflg;
 	char prtfilename[32];
-	char hostname[9],comment[81];
-	char native[8];
+	char hostname[9];
 	short numsmp,smpint,numtrc;
 	short  numaux, cdpfold, origsmpint, orignumsmp;
 	int line_hdr_indx,trace_hdr_indx;
 	int indx,bytes,help,databytes,segydatabytes;
+#if ( BYTE_ORDER == LITTLE_ENDIAN )
+	char native[8];
 	int native_line_header, native_trace_header, native_trace_data;
-	short samples;
+	int format,index,length;
+#endif
 	char ntap[256],otap[256],map_file[256];
 	char *def_map_file;
 	char *header,*buffer;
@@ -52,15 +55,8 @@ char **argv;
 	int lval;
 	float rval;
 	char *chval;
-	int format,index,length;
 	int TrcNumSmp_format, TrcNumSmp_index, TrcNumSmp_length;
 	int TrcIdCode_format, TrcIdCode_index, TrcIdCode_length;
-	int ElevScaler_format, ElevScaler_index, ElevScaler_length;
-	int XYUnits_format, XYUnits_index, XYUnits_length;
-	int RecNum_format, RecNum_index, RecNum_length;
-	int TrcNum_format, TrcNum_index, TrcNum_length;
-	int SrcX_format, SrcX_index, SrcX_length;
-	int SrcY_format, SrcY_index, SrcY_length;
 	int FieldRecNum_format, FieldRecNum_index, FieldRecNum_length;
 	int FieldTrcNum_format, FieldTrcNum_index, FieldTrcNum_length;
 	int LineTrcNum_format, LineTrcNum_index, LineTrcNum_length;
@@ -79,15 +75,15 @@ char **argv;
 	save_struct **line_hdr_map,**trace_hdr_map;
 
 	short fmtcode,unitsflg;
-	int *hdrtype;
 	int jobnum;
 	int linenum, reelnum;
 	int linetrcnum;
 	int segy_prrcnm, segy_prtrnm;
 	short trid, trcnumsmp, segysmpint;
 	int cdpnum, cdptrcnum;
-	int hlhknt;
-	char **hlh;
+	int hlhknt,hlh_byte_total;
+	char *hlh[40]; /* this is limited to 40 lines in the SEGY data */
+	short hlh_entry_length;
 	int read_map_file();
 
 	help = C_ARGIS("-?",&argc,argv);
@@ -198,7 +194,6 @@ char **argv;
 	if (verbose == 1) fprintf(prtfile," output file = ");
 	if (strcmp(otap," ") == 0) {
 	  if (verbose == 1) fprintf(prtfile,"stdout\n");
-	  output = (FILE *)stdout;
 	  luout = 1;
 	  }
 	else {
@@ -206,6 +201,7 @@ char **argv;
 	  C_LBOPEN(&luout,otap,"w");
 	  }
 
+#if ( BYTE_ORDER == LITTLE_ENDIAN )
 	native_line_header = 0;
 	native_trace_header = 0;
         native_trace_data = 0;
@@ -226,6 +222,7 @@ char **argv;
 	    native_trace_data = 1;
 	    }
 	  }
+#endif
 /*
 need to check return codes ; we should also realloc after looking up indices
 */
@@ -250,20 +247,33 @@ need to check return codes ; we should also realloc after looking up indices
 	  fprintf(stderr,"%s: ERROR reading SEGY line header\n", argv[0]);
 	  exit(1);
 	  }
-	
+
+/* pull the EBCDIC header and save in an hlh array */
+
 	count=3200;
 	F_EBCASC(buffer,buffer,&count);
-	comment[80] = '\0';
-	if (verbose != 0) {
-	  fprintf(prtfile,"\n EBCDIC header:\n");
-	  for (i=0;i<40; i++) {
-	    memcpy(comment,buffer+(i*80),80);
-	    fprintf(prtfile,"%-80s\n",comment);
+	hlhknt=0;
+	if (verbose != 0) fprintf(prtfile,"\n EBCDIC header:\n");
+	for (i=0;i<40; i++) {
+	  hlh_entry_length=81;
+	  for (j=79; j>=0 && hlh_entry_length>80; j--) {
+	    if (*(buffer+(i*80)+j) != ' ') hlh_entry_length = j-4;
+	    }
+	  if (hlh_entry_length > 0) {
+	    hlhknt++;
+	    hlh_entry_length++;
+	    hlh[hlhknt-1] = (char *) malloc(hlh_entry_length+1);
+	    if (hlh[hlhknt-1] == NULL) {
+	      fprintf(stderr,"SEGY2USP ERROR - unable to allocate requested space (%d bytes)\n",hlh_entry_length+1);
+	      exit(1);
+	      }
+	    strncpy(hlh[hlhknt-1],buffer+(i*80)+4,hlh_entry_length);
+	    if (verbose != 0) fprintf(prtfile,"%d %s\n",hlhknt,hlh[hlhknt-1]);
 	    }
 	  }
+	if (verbose != 0) fprintf(prtfile,"\n");
 
-/* put the EBCDIC header into HLH
-*/
+/* put the EBCDIC header into HLH */
 
 	if ((buffer = (char *)realloc(buffer,SEGYLINEHEADERBYTES)) == NULL) {
 	  fprintf(stderr,"%s: ERROR mallocing %d bytes of memory\n",
@@ -561,7 +571,10 @@ if (errno != 0) {fprintf(stderr,"errno = %d\n",errno); perror("Invalid"); }
 	for (indx=0;indx<line_hdr_indx;indx++) {
 	  if (strcmp(line_hdr_map[indx]->tag,"NumSmp") == 0) {
 	    numsmpflg = 1;
-	    switch(segy_line_hdr_map[indx].format) {
+	    if (segy_line_hdr_map[indx].length == -1)
+	      numsmp = atoi(segy_line_hdr_map[indx].tag);
+	    else
+	      switch(segy_line_hdr_map[indx].format) {
 		case (SAVE_DUMMY_DEF):
 		case (SAVE_SHORT_DEF):
 		    get_indexed_hw_val(buffer,segy_line_hdr_map[indx].format,
@@ -602,7 +615,11 @@ if (errno != 0) {fprintf(stderr,"errno = %d\n",errno); perror("Invalid"); }
 	  exit(0);
 	  }
 
-	if ((header = (char *)malloc(HSTOFF)) == NULL) {
+/* I got lazy here and just assumed a max HLH of 3200 - that's the SEGY max 
+   and we're substituting two bytes lenght entries for the 'C ##' characters
+   on the SEGY entries
+*/
+	if ((header = (char *)malloc(HSTOFF+3200)) == NULL) {
 	  fprintf(stderr,"%s: failure mallocing %d bytes of memory for USP output\n",
 		argv[0],HSTOFF);
 	  fprintf(prtfile,"%s: failure mallocing %d bytes of memory for USP output\n",
@@ -687,13 +704,26 @@ if (errno != 0) {fprintf(stderr,"errno = %d\n",errno); perror("Invalid"); }
 		  }
 		}
 
+	nbytes=HSTOFF;
+	bufptr=header+HSTOFF;
+	hlh_byte_total=4;
+	for (i=0; i<hlhknt; i++) {
+	  hlh_entry_length = strlen(hlh[i]);
+	  hlh_byte_total += HLHINT + hlh_entry_length;
+	  nbytes += hlh_entry_length + HLHINT;
+	  /* *(short *)bufptr = hlh_entry_length; - alignment problems */
+	  memcpy(bufptr, &hlh_entry_length, 2);
+	  bufptr+=HLHINT;
+	  memcpy(bufptr,hlh[i],hlh_entry_length);
+	  bufptr+=hlh_entry_length;
+	  }
 	put_hw_val(header,"PrcDat",LINEHEADER,cgdate());
-	put_hw_val(header,"HlhEnt",LINEHEADER,0);
-	put_hw_val(header,"HlhByt",LINEHEADER,4);
-	C_WRTAPE(luout,header,HSTOFF);
+	put_hw_val(header,"HlhEnt",LINEHEADER,hlhknt);
+	put_hw_val(header,"HlhByt",LINEHEADER,hlh_byte_total);
+	C_WRTAPE(luout,header,nbytes);
 	if (bytes == 0) {
 	  fprintf(stderr,"%s: error writing header (%d bytes attempted)\n",
-		argv[0],HSTOFF);
+		argv[0],nbytes);
 	  exit(1);
 	  }
 	  
@@ -913,10 +943,9 @@ if (errno != 0) {fprintf(stderr,"errno = %d\n",errno); perror("Invalid"); }
 			header+SZTRHD+(j*sizeof(float)));
 */
 #if ( BYTE_ORDER == LITTLE_ENDIAN )
-		        if (native_trace_data != 1)
-	  		  HTOCL(buffer+SZTRHD,numsmp);
+	  		/* HTOCL(buffer+SZTRHD,numsmp); */
 			ibm_to_float(buffer+SEGYTRACEHEADERBYTES,
-				header+SZTRHD,numsmp,0);
+				header+SZTRHD,numsmp,native_trace_data);
 #else
 			ibm_to_float(buffer+SEGYTRACEHEADERBYTES,
 				header+SZTRHD,numsmp,1);
