@@ -418,20 +418,23 @@ void defaults_fileCB(Widget w, XtPointer client_data, XtPointer call_data)
 				    XmNorientation,XmHORIZONTAL,
 				    XmNadjustLast,False,
 				    XmNentryAlignment,XmALIGNMENT_CENTER,
-				    XmNpacking,XmPACK_COLUMN,
+				    XmNpacking,XmPACK_TIGHT,
+				    XmNmarginHeight,10,
+				    XmNmarginWidth,10,
 				    XmNnumColumns,1,
-				    XmNspacing,30, 
+				    XmNspacing,10, 
 				    XmNtopAttachment,XmATTACH_WIDGET,
 				    XmNtopWidget,separator,
-				    XmNtopOffset,10,
+				    XmNtopOffset,0,
 				    XmNbottomAttachment,XmATTACH_FORM, 
+				    XmNbottomOffset,0,
 				    XmNleftAttachment,XmATTACH_FORM, 
-				    XmNleftOffset,10,
+				    XmNleftOffset,0,
 				    XmNrightAttachment,XmATTACH_FORM, 
-				    XmNrightOffset,10,
+				    XmNrightOffset,0,
 				    NULL);
 
-  button=XmCreatePushButtonVa(dialog_window,"Load",NULL);
+  button=XmCreatePushButtonVa(dialog_window,"Load from File",NULL);
   XtAddCallback(button,XmNactivateCallback,set_typeCB,(XtPointer)4L); 
   XtAddCallback(button,XmNactivateCallback,filer_promptCB,client_data); 
   XtAddCallback(button,XmNactivateCallback,destroyCB,dialog_form); 
@@ -439,7 +442,7 @@ void defaults_fileCB(Widget w, XtPointer client_data, XtPointer call_data)
   message=(ClientData *)malloc(sizeof(ClientData));
   message->w=dialog_form;
   message->id=id;
-  button=XmCreatePushButtonVa(dialog_window,"Save",NULL);
+  button=XmCreatePushButtonVa(dialog_window,"Save to File",NULL);
   XtManageChild(button);
   XtAddCallback(button,XmNactivateCallback,get_defaultsCB,message); 
   XtAddCallback(button,XmNactivateCallback,set_typeCB,(XtPointer)5L); 
@@ -448,7 +451,7 @@ void defaults_fileCB(Widget w, XtPointer client_data, XtPointer call_data)
   message=(ClientData *)malloc(sizeof(ClientData));
   message->w=dialog_form;
   message->id=id;
-  button=XmCreatePushButtonVa(dialog_window," Default ",NULL);
+  button=XmCreatePushButtonVa(dialog_window,"Save as Default",NULL);
   XtManageChild(button);
   XtAddCallback(button,XmNactivateCallback,get_defaultsCB,message); 
   XtAddCallback(button,XmNactivateCallback,save_as_defaultCB,(XtPointer)id); 
