@@ -242,8 +242,9 @@ void init_global(void)
   Widget row_column;
   Widget button;
   Widget paned_window;
+#ifdef VIEW3D
   Visual *vis;
-
+#endif
 
   n=0;
   XtSetArg(args[n],XtNargc,savedArgc); n++;     /* RJM: added 1/17/97 */
@@ -715,7 +716,6 @@ void delete_severalCB(Widget w, XtPointer client_data, XtPointer call_data)
 */
 void squishCB(Widget w, XtPointer client_data, XtPointer call_data)
 {
-  Widget info;
   int width,height,root_x,root_y;
   long id;	/* RJM: handle 64-bit architectures */
 
@@ -725,20 +725,6 @@ void squishCB(Widget w, XtPointer client_data, XtPointer call_data)
 
   locate_cursor(&root_x,&root_y);
 
-  /*
-  info=XmCreateInformationDialogVa(xdisplay[id].window,"error_message",
-				   XmNdefaultPosition,False,
-				   XmNx,root_x,
-				   XmNy,root_y,
-				   XmNmessageString,
-				   XMstr("Press the button in the upper lefthand corner to return the controls."),
-				   XmNdialogTitle,
-				   XMstr("Information Message"),
-				   NULL);
-  XtAddCallback(info,XmNokCallback,destroyCB,info);
-  XtAddCallback(info,XmNcancelCallback,destroyCB,info);
-  */
-
 
   xdisplay[id].mode=1;		/* Squish mode is same as picking. */
   set_mode_label(1,id);
