@@ -22,6 +22,8 @@ Boolean toggle_value[2];
 static int start_trace=1,skip_trace=3,zero_line=0;
 static Pixel foreground;
 static float wiggle_scale=1.0,overlap=10,scale_x=2.0,scale_y=1.0;
+    
+extern void vlint_( float*, int*, float*, int*, float*, int*, int* );
 
 
 /*
@@ -448,43 +450,43 @@ RJM: commented out 1/17/97 */
 */
 void create_wiggle(int image_count, long id, int width_temp, int height_temp)
 {
-  int x,y,fill,value,value_old=0,stride1,stride2,skip_tmp;
+  int i,x,y,fill,value,value_old=0,stride1,stride2,skip_tmp;
   int middle,temp_value,count,id_parent,start_x,start_y,temp_offset;
-  float scale,sample;
+  float scale,del;
   float *trash,*trash_in,*trash_out;
   struct values_struct values;
   struct location_struct location;
 
-				/* Get the background and foreground colors. */
+  /* Get the background and foreground colors. */
   XtSetArg(args[0],XmNbackground,&xdisplay[image_count].background);
   XtGetValues(draw_background,args,1);
   XtSetArg(args[0],XmNbackground,&foreground);
   XtGetValues(draw_wiggle,args,1);
 
-  raster[image_count]=(unsigned char *)malloc(width_temp*height_temp
-		      *sizeof(char));	/* RJM: moved here from calling func */
+  raster[image_count]=(unsigned char *)malloc(width_temp*height_temp*sizeof(char));
 
-				/* Initialize the image to the background. */
+  /* Initialize the image to the background. */
   memset((char *)raster[image_count],(int)(xdisplay[id].background&0xffffffff),width_temp*height_temp*sizeof(char));
-
-				/* Find the middle or zero value. */
+				
+  /* Find the middle or zero value. */
   middle=(end_color+start_color)/2;
-
-				/* Compute the scale factor. */
+				
+  /* Compute the scale factor. */
   scale=overlap/100.0;
 
   id_parent=xdisplay[id].parent;
 
-				/* Scale by zoom factor. */
+  /* Scale by zoom factor. */
   skip_tmp=scale_x*skip_trace/xdisplay[id].pick_x; 
 
-				/* Create some temporary space. */
+  /* Create some temporary space. */
   trash=(float *)malloc(height_temp*sizeof(float));
   trash_in=(float *)malloc(height_temp*sizeof(float));
   trash_out=(float *)malloc(height_temp*sizeof(float));
 
-				/* Loop through the traces. */
-  for (x=start_trace; x<width_temp; x+=skip_tmp) {
+  /* Loop through the traces. */
+  /* for (x=start_trace; x<width_temp; x+=skip_tmp) { */
+  for (x=skip_tmp/2; x<width_temp; x+=skip_tmp) {
     stride1=1;
     stride2=xdisplay[id_parent].image->width;
     temp_value=xdisplay[id_parent].image->height;
@@ -494,31 +496,24 @@ void create_wiggle(int image_count, long id, int width_temp, int height_temp)
     start_x=location.x;
     start_y=location.y;
     location=get_location(values.record,values.trace,esamp[id],id_parent);
-    for (count=start_y; count<location.y; count++)
-      *(trash_in+count-start_y)=(float)(*(raster[id_parent]+(int)(start_x/xdisplay[id_parent].pick_x)+((int)(count/xdisplay[id_parent].pick_y)*stride2)));
-
-    count=0;
-    for (sample=start_y; sample<location.y; sample+=xdisplay[id].pick_y/scale_y) { 
-      *(trash+count)=sample-start_y;
-      count++;
+    del=xdisplay[id].pick_y;
+    if (del > 1.0) del=1.0;
+    for (count=0;count<height_temp;count++) {
+      *(trash+count)=(float)(count*del/scale_y);
+      y=(int)((count+start_y)/del);
+      if (y >= temp_value) {
+	*(trash_in+count)=(float)(*(trash_in+count-1));
+      } else {
+	*(trash_in+count)=(float)(*(raster[id_parent]
+	     +(int)(start_x/xdisplay[id_parent].pick_x)+y*stride2));
+      }
     }
-    count=height_temp-2;
-    *(trash+count)=*(trash+count-2);
-    *(trash+count-2)=*(trash+count-3)+(*(trash+count)-(*(trash+count-3)))/3.0;
-    *(trash+count-1)=*(trash+count-3)+2*(*(trash+count)-(*(trash+count-3)))/3.0;
+				
+    /* Do a linear interplation. */
+    vlint_(trash_in,&height_temp,trash,&stride1,trash_out,&stride1,&height_temp);
+    *(trash_out+height_temp-1)=(float)(*(trash_in+height_temp-1));
 
-    temp_value=(location.y-start_y+1);
-
-				/* Do a linear interplation. */
-/* #ifdef SUN */        /* RJM: commented out */
-#if defined(sun) || defined(__sgi)
-{
-    extern void vlint_( float*, int*, float*, int*, float*, int*, int* );
-    vlint_(trash_in,&temp_value,trash,&stride1,trash_out,&stride1,&height_temp);
-}
-#endif
-
-				/* Plot wiggle for each sample. */
+    /* Plot wiggle for each sample. */
     for (y=0; y<height_temp; y++) {
       temp_value=wiggle_scale*((int)(*(trash_out+y))-middle);
       if (temp_value>((int)end_color-middle)) 
@@ -527,48 +522,53 @@ void create_wiggle(int image_count, long id, int width_temp, int height_temp)
 	temp_value=(int)start_color-middle;
       value=(int)(temp_value*scale);
       if (value==value_old) {
-	temp_offset=x+(y*width_temp)+value;
+	temp_offset=x+value;
 	if (temp_offset<0) temp_offset=0;
-	if (((value+x)>=0)&&((value+x)<width_temp)&&(value!=0))
+	else if (temp_offset>=width_temp) temp_offset=width_temp;
+	temp_offset=temp_offset+y*width_temp;
+	if (((value+x)>=0)&&((value+x)<width_temp)&&(value!=0)) {
 	  *(raster[image_count]+temp_offset)=foreground&0xffffffff;
-	else {
-	  if (zero_line==0)
+	} else {
+	  if (zero_line==0) {
 	    *(raster[image_count]+temp_offset)=foreground&0xffffffff;
-	  else
-	    if ((((x/skip_tmp)%zero_line)==0)&&(zero_line!=1))
+	  } else {
+	    if ((((x/skip_tmp)%zero_line)==0)&&(zero_line!=1)) {
 	      *(raster[image_count]+temp_offset)=foreground&0xffffffff;
-	}      
+	    }
+	  }  
+	}    
       }
 
       if ((toggle_value[0])&&((value_old)>0))
 	for (fill=0; fill<=value; fill++) {
-	  if (((fill+x)>=0)&&((fill+x)<width_temp))
+	  if (((fill+x)>=0)&&((fill+x)<width_temp)) {
 	    *(raster[image_count]+x+(y*width_temp)+fill)=foreground&0xffffffff;
+	  }
 	}
       else
 	for (fill=value_old+1; fill<=value; fill++) {
-	  if (((fill+x)>=0)&&((fill+x)<width_temp))
+	  if (((fill+x)>=0)&&((fill+x)<width_temp)) {
 	    *(raster[image_count]+x+(y*width_temp)+fill)=foreground&0xffffffff;
+	  }
 	}
 
       if ((toggle_value[1])&&((value_old)<0))
 	for (fill=value; fill<=0; fill++) {
-	  if (((fill+x)>=0)&&((fill+x)<width_temp))
+	  if (((fill+x)>=0)&&((fill+x)<width_temp)) {
 	    *(raster[image_count]+x+(y*width_temp)+fill)=foreground&0xffffffff;
+	  }
 	}
       else
 	for (fill=value; fill<=value_old-1; fill++) {
-	  if (((fill+x)>=0)&&((fill+x)<width_temp))
+	  if (((fill+x)>=0)&&((fill+x)<width_temp)) {
 	    *(raster[image_count]+x+(y*width_temp)+fill)=foreground&0xffffffff;
+	  }
 	}
       value_old=value;
     }
   }
 
-  if(trash)
-    free((char*)trash); trash=NULL;
-  if(trash_in)
-    free((char*)trash_in); trash_in=NULL;
-  if(trash_out)
-    free((char*)trash_out); trash_out=NULL;
+  if(trash) free((char*)trash); trash=NULL;
+  if(trash_in) free((char*)trash_in); trash_in=NULL;
+  if(trash_out) free((char*)trash_out); trash_out=NULL;
 }
