@@ -1,8 +1,3 @@
-/***********************************************************************
- *                copyright 2001, Amoco Production Company             *
- *                            All Rights Reserved                      *
- *                    an affiliate of BP America Inc.                  *
- ***********************************************************************/
 /*
    This routine is designed to look at a USP line header and return
    an array of character strings containing the historical line header 
@@ -32,9 +27,17 @@ char ***hlh_entries;
 	  HTOCS(offset,1);
 #endif
 	  memcpy(&temp,offset,sizeof(short));
+#if ( BYTE_ORDER == LITTLE_ENDIAN )
+	  HTOCS(&temp,1);
+#endif
 	  hlh_entry_length = temp;
 	  offset+=HLHINT;
-	  *(*hlh_entries+i) = (char *)malloc(hlh_entry_length+1);
+	  *(*hlh_entries+i) = (char *)calloc(hlh_entry_length+1,1);
+	  if (*(*hlh_entries+i) == NULL) {
+	    fprintf(stderr, "aborting in gethlh, unable to allocate buffer of %d bytes\n", hlh_entry_length+1);
+	    hlh_num_entries = i-1;
+	    return((int)hlh_num_entries);
+	    }
 	  memcpy(*(*hlh_entries+i),offset,hlh_entry_length);
 	  offset+=hlh_entry_length;
 	  }
