@@ -24,6 +24,7 @@
 /* 17sep93 phil fincannon - added pick option                  */
 /* 15nov93 phil fincannon - new alert warning for file write er*/
 /* 08dec93 phil fincannon - uppercase keyword option           */
+/* 07aug01 joe m. wade    - upped MAXSEL to 4096               */
 
 #include <stdlib.h>
 #include <unistd.h>
@@ -55,7 +56,7 @@
 #define XSET(a,n,v) {Arg *t=&(a); t->name=(n); t->value=(XtArgVal)(v);}
 #define XDEF(str)   XmStringCreateLtoR((str),XmSTRING_DEFAULT_CHARSET)
 
-#define MAXSEL 1024 /* maximum selection widget entrys + 1 */
+#define MAXSEL 4096 /* maximum selection widget entrys + 1 */
 
 typedef struct { char *iconfile;
                  char *dismiss;
@@ -461,7 +462,7 @@ Widget make_menu_item (item_name, client_data, menu)
 
 /* -------------------------------------------------------------------- */
 
-main (argc, argv) /* build a panel to view/update explore env file */
+void main (argc, argv) /* build a panel to view/update explore env file */
    int argc;
    char **argv;
 {
